@@ -769,7 +769,7 @@ test('custom cache support', async t => {
 });
 
 test.serial('fallback works', async t => {
-	const cacheable = new CacheableLookup({resolver, fallbackDuration: 3600});
+	const cacheable = new CacheableLookup({resolver, fallbackDuration: 0.1});
 	resolver.resetCounter();
 
 	const entries = await cacheable.lookupAsync('osHostname', {all: true});
@@ -788,8 +788,12 @@ test.serial('fallback works', async t => {
 	t.deepEqual(resolver.counter, {
 		6: 1,
 		4: 1,
-		lookup: 2
+		lookup: 3
 	});
+
+	await sleep(100);
+
+	t.is(cacheable._hostnamesToFallback.size, 0);
 });
 
 test.serial('fallback works if ip change', async t => {
@@ -865,7 +869,7 @@ test('real DNS queries first', async t => {
 });
 
 test('fallback can be turned off', async t => {
-	const cacheable = new CacheableLookup({resolver, fallbackDuration: 0});
+	const cacheable = new CacheableLookup({resolver, lookup: false});
 
 	await t.throwsAsync(cacheable.lookupAsync('osHostname', {all: true}), {
 		message: 'cacheableLookup ENOTFOUND osHostname'
@@ -1011,12 +1015,21 @@ test('slow dns.lookup', async t => {
 		resolver,
 		lookup: (hostname, options, callback) => {
 			t.is(hostname, 'osHostname');
-			t.deepEqual(options, {all: true});
+			t.is(options.all, true);
+			t.true(options.family === 4 || options.family === 6);
 
 			setTimeout(() => {
-				callback(null, [
-					{address: '127.0.0.1', family: 4}
-				]);
+				if (options.family === 4) {
+					callback(null, [
+						{address: '127.0.0.1', family: 4}
+					]);
+				}
+
+				if (options.family === 6) {
+					callback(null, [
+						{address: '::1', family: 6}
+					]);
+				}
 			}, 10);
 		}
 	});
@@ -1028,3 +1041,17 @@ test('slow dns.lookup', async t => {
 		family: 4
 	});
 });
+
+test.cb.failing('throws original lookup error if not recognized', t => {
+	const cl = new CacheableLookup({
+		lookup: (hostname, options, callback) => {
+			callback(new Error('Fake DNS error'));
+		}
+	});
+
+	cl.lookup('example.test', error => {
+		t.is(error.message, 'Fake DNS error');
+
+		t.end();
+	});
+});
